# Copyright (C) 2010-2023 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/

import urllib.parse

from rhodecode.lib.vcs import CurlSession
from rhodecode.lib.ext_json import json


def call_service_api(service_api_host, service_api_token, api_url, payload):

    payload.update({
        'id': 'service',
        'auth_token': service_api_token
    })

    service_api_url = urllib.parse.urljoin(service_api_host, api_url)
    response = CurlSession().post(service_api_url, json.dumps(payload))

    if response.status_code != 200:
        raise Exception(f"Service API at {service_api_url} responded with error: {response.status_code}")

    return json.loads(response.content)['result']
